ComplexEOF
==========

.. currentmodule:: xeofs.single

.. autoclass:: ComplexEOF
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ComplexEOF.__init__
      ~ComplexEOF.components
      ~ComplexEOF.components_amplitude
      ~ComplexEOF.components_phase
      ~ComplexEOF.compute
      ~ComplexEOF.deserialize
      ~ComplexEOF.explained_variance
      ~ComplexEOF.explained_variance_ratio
      ~ComplexEOF.fit
      ~ComplexEOF.fit_transform
      ~ComplexEOF.get_params
      ~ComplexEOF.get_serialization_attrs
      ~ComplexEOF.inverse_transform
      ~ComplexEOF.load
      ~ComplexEOF.save
      ~ComplexEOF.scores
      ~ComplexEOF.scores_amplitude
      ~ComplexEOF.scores_phase
      ~ComplexEOF.serialize
      ~ComplexEOF.singular_values
      ~ComplexEOF.transform
   
   

   
   
   